<?php
session_start();
include 'license_check.php';
include 'db_connect.php';

// Überprüfung, ob der Benutzer angemeldet ist
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

// Daten für Berichte abrufen

// 1. Gesamtübersicht über Lagerbestände
$stmt = $pdo->query('SELECT SUM(kapazitaet) AS gesamt_kapazitaet, SUM(belegung) AS gesamt_belegung FROM lagerplaetze');
$lagerGesamt = $stmt->fetch();

// 2. Auslastung pro Lagerplatz
$stmt = $pdo->query('SELECT name, kapazitaet, belegung FROM lagerplaetze');
$lagerplaetze = $stmt->fetchAll();

// 3. Top 5 ausgelastete Lagerplätze
$stmt = $pdo->query('
    SELECT name, kapazitaet, belegung, (belegung/kapazitaet)*100 AS auslastung_prozent
    FROM lagerplaetze
    WHERE kapazitaet > 0
    ORDER BY auslastung_prozent DESC
    LIMIT 5
');
$topAusgelastet = $stmt->fetchAll();

// 4. Lagerplätze mit Überkapazität (Belegung > Kapazität)
$stmt = $pdo->query('
    SELECT name, kapazitaet, belegung
    FROM lagerplaetze
    WHERE belegung > kapazitaet
');
$ueberkapazitaet = $stmt->fetchAll();

// 5. Inventurdifferenzen
$stmt = $pdo->query('
    SELECT lp.name, ip.alter_belegung, ip.neuer_belegung, (ip.neuer_belegung - ip.alter_belegung) AS differenz, ip.datum
    FROM inventur_protokoll ip
    JOIN lagerplaetze lp ON ip.lagerplatz_id = lp.id
    WHERE ip.alter_belegung IS NOT NULL AND ip.neuer_belegung IS NOT NULL
    ORDER BY ip.datum DESC
    LIMIT 10
');
$inventurDifferenzen = $stmt->fetchAll();

// 6. Lagerplätze mit dem meisten freien Platz
$stmt = $pdo->query('
    SELECT name, kapazitaet, belegung, (kapazitaet - belegung) AS freier_platz
    FROM lagerplaetze
    WHERE kapazitaet > belegung
    ORDER BY freier_platz DESC
    LIMIT 5
');
$meisteFreierPlatz = $stmt->fetchAll();
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Berichte - Lagerverwaltung Cockpit</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;700&display=swap" rel="stylesheet">
    <!-- Eigenes CSS -->
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            background-color: #f4f6f9;
            padding-bottom: 70px; /* Platz für die mobile Navigation */
            transition: background-color 0.5s;
        }

        /* Navbar Styling */
        .navbar {
            height: 86px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            transition: background-color 0.5s, box-shadow 0.5s;
        }

        .navbar-brand {
            font-weight: bold;
            font-size: 1.5rem;
            height: 66px;
        }

        .navbar-brand img {
            height: 100%; /* Höhe des Logos auf die Höhe der Navbar setzen */
            width: auto; /* Proportionen beibehalten */
            object-fit: contain; /* Falls nötig, das Logo anpassen */
        }

        .nav-link {
            color: #ffffff !important;
            transition: color 0.3s;
        }

        .nav-link:hover, .nav-link.active {
            color: #ff6f61 !important;
        }

        /* Card Styling */
        .card {
            border-radius: 15px;
            box-shadow: 0 4px 8px rgba(0,0,0,0.05);
            transition: transform 0.3s, box-shadow 0.3s;
        }

        .card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 16px rgba(0,0,0,0.2);
        }

        .card-header {
            border-bottom: none;
            border-top-left-radius: 15px;
            border-top-right-radius: 15px;
        }

        .card-body {
            animation: fadeIn 0.5s ease-in-out;
        }

        /* Tabellen Styling */
        table {
            border-collapse: collapse;
        }

        th, td {
            padding: 12px 15px;
            vertical-align: middle;
            text-align: center;
        }

        thead {
            background-color: #ff6f61;
            color: #ffffff;
        }

        tbody tr:nth-child(even) {
            background-color: #f9f9f9;
        }

        tbody tr:hover {
            background-color: #f1f1f1;
        }

        /* Mobile Bottom Navigation */
        .mobile-nav {
            display: none;
        }

        @media (max-width: 767.98px) {
            .mobile-nav {
                display: flex;
                position: fixed;
                bottom: 0;
                left: 0;
                right: 0;
                background-color: #343a40;
                border-top: 1px solid #495057;
                justify-content: space-around;
                padding: 10px 0;
                z-index: 1000;
            }
            .mobile-nav a {
                color: #adb5bd;
                text-decoration: none;
                font-size: 0.85em;
                text-align: center;
                flex: 1;
                display: flex;
                flex-direction: column;
                align-items: center;
            }
            .mobile-nav a i {
                font-size: 1.5em;
                margin-bottom: 2px;
            }
            .mobile-nav a.active {
                color: #ffffff;
            }
        }

        /* Animation */
        @keyframes fadeIn {
            from { opacity: 0; transform: translateY(-10px); }
            to { opacity: 1; transform: translateY(0); }
        }

        /* Diagramme */
        canvas {
            background-color: #ffffff;
            border-radius: 15px;
            padding: 15px;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
            transition: transform 0.3s;
        }

        canvas:hover {
            transform: scale(1.02);
        }
    </style>
</head>
<body>

<!-- Navigation für Desktop -->
<nav class="navbar navbar-expand-lg navbar-dark bg-dark d-none d-md-block">
  <div class="container-fluid">
    <a class="navbar-brand" href="index.php"><img src="img/logo.png"></a>
    <div class="collapse navbar-collapse justify-content-end">
       <ul class="navbar-nav">
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
                 <i class="bi bi-speedometer2 me-1"></i>Dashboard
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
                 <i class="bi bi-list-task me-1"></i>Aufgaben
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
                 <i class="bi bi-box-seam me-1"></i>Lagerplätze
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="bericht.php">
                 <i class="bi bi-bar-chart-fill me-1"></i>Berichte
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
                 <i class="bi bi-gear-fill"></i>Einstellungen
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="logout.php">
                 <i class="bi bi-box-arrow-right me-1"></i>Abmelden
             </a>
         </li>
       </ul>
    </div>
  </div>
</nav>

<!-- Mobile Bottom Navigation -->
<div class="mobile-nav d-md-none">
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
        <i class="bi bi-speedometer2"></i>
        Dashboard
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
        <i class="bi bi-list-task"></i>
        Aufgaben
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
        <i class="bi bi-box-seam"></i>
        Lagerplätze
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
        <i class="bi bi-bar-chart-fill"></i>
        Berichte
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
        <i class="bi bi-gear-fill"></i>
        Einstellungen
    </a>
    <a href="logout.php">
        <i class="bi bi-box-arrow-right"></i>
        Abmelden
    </a>
</div>

<div class="container my-4">
    <h2 class="mb-4 text-center text-primary"><i class="bi bi-bar-chart-fill me-2"></i> Berichte und Analysen</h2>

    <!-- Gesamtübersicht -->
    <div class="card mb-4">
        <div class="card-header bg-primary text-white">
            <i class="bi bi-graph-up me-2"></i>Gesamtübersicht über Lagerbestände
        </div>
        <div class="card-body">
            <div class="row text-center">
                <div class="col-md-4 mb-3">
                    <h5>Gesamtkapazität</h5>
                    <p class="display-6"><?php echo number_format($lagerGesamt['gesamt_kapazitaet'], 0, ',', '.'); ?></p>
                </div>
                <div class="col-md-4 mb-3">
                    <h5>Gesamtbelegung</h5>
                    <p class="display-6"><?php echo number_format($lagerGesamt['gesamt_belegung'], 0, ',', '.'); ?></p>
                </div>
                <div class="col-md-4 mb-3">
                    <h5>Gesamtauslastung</h5>
                    <p class="display-6"><?php
                        $gesamtAuslastung = ($lagerGesamt['gesamt_kapazitaet'] > 0) ? ($lagerGesamt['gesamt_belegung'] / $lagerGesamt['gesamt_kapazitaet']) * 100 : 0;
                        echo round($gesamtAuslastung, 2); ?>%
                    </p>
                </div>
            </div>
            <canvas id="gesamtAuslastungChart" height="150"></canvas>
        </div>
    </div>

    <!-- Lagerplätze mit dem meisten freien Platz -->
    <div class="card mb-4">
        <div class="card-header bg-success text-white">
            <i class="bi bi-box-seam me-2"></i>Lagerplätze mit dem meisten freien Platz
        </div>
        <div class="card-body">
            <?php if (count($meisteFreierPlatz) > 0): ?>
            <div class="table-responsive">
                <table class="table table-hover">
                    <thead>
                        <tr>
                            <th>Lagerplatz</th>
                            <th>Kapazität</th>
                            <th>Belegung</th>
                            <th>Freier Platz</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($meisteFreierPlatz as $lager): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($lager['name']); ?></td>
                            <td><?php echo number_format($lager['kapazitaet'], 0, ',', '.'); ?></td>
                            <td><?php echo number_format($lager['belegung'], 0, ',', '.'); ?></td>
                            <td><?php echo number_format($lager['freier_platz'], 0, ',', '.'); ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
            <?php else: ?>
            <p>Alle Lagerplätze sind voll belegt oder haben keine Kapazität.</p>
            <?php endif; ?>
        </div>
    </div>

    <!-- Top 5 ausgelastete Lagerplätze -->
    <div class="card mb-4">
        <div class="card-header bg-warning">
            <i class="bi bi-graph-up-arrow me-2"></i>Top 5 der am stärksten ausgelasteten Lagerplätze
        </div>
        <div class="card-body">
            <canvas id="topAusgelastetChart" height="200"></canvas>
        </div>
    </div>

    <!-- Lagerplätze mit Überkapazität -->
    <?php if (count($ueberkapazitaet) > 0): ?>
    <div class="card mb-4">
        <div class="card-header bg-danger text-white">
            <i class="bi bi-exclamation-triangle-fill me-2"></i>Lagerplätze mit Überkapazität
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Lagerplatz</th>
                            <th>Kapazität</th>
                            <th>Belegung</th>
                            <th>Überbelegung</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($ueberkapazitaet as $lager): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($lager['name']); ?></td>
                            <td><?php echo number_format($lager['kapazitaet'], 0, ',', '.'); ?></td>
                            <td><?php echo number_format($lager['belegung'], 0, ',', '.'); ?></td>
                            <td><?php echo number_format($lager['belegung'] - $lager['kapazitaet'], 0, ',', '.'); ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
    <?php endif; ?>

    <!-- Inventurdifferenzen -->
    <div class="card mb-4">
        <div class="card-header bg-info text-white">
            <i class="bi bi-clock-history me-2"></i>Letzte Inventurdifferenzen
        </div>
        <div class="card-body">
            <?php if (count($inventurDifferenzen) > 0): ?>
            <div class="table-responsive">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Datum</th>
                            <th>Lagerplatz</th>
                            <th>Alter Bestand</th>
                            <th>Neuer Bestand</th>
                            <th>Differenz</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($inventurDifferenzen as $diff): ?>
                        <tr>
                            <td><?php echo date('d.m.Y H:i', strtotime($diff['datum'])); ?></td>
                            <td><?php echo htmlspecialchars($diff['name']); ?></td>
                            <td><?php echo number_format($diff['alter_belegung'], 0, ',', '.'); ?></td>
                            <td><?php echo number_format($diff['neuer_belegung'], 0, ',', '.'); ?></td>
                            <td><?php echo ($diff['differenz'] > 0) ? '+' : ''; echo number_format($diff['differenz'], 0, ',', '.'); ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
            <?php else: ?>
            <p>Keine Inventurdifferenzen vorhanden.</p>
            <?php endif; ?>
        </div>
    </div>
</div>


<!-- Bootstrap JS und Chart.js -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>

<!-- JavaScript zur Initialisierung der Diagramme -->
<script>
document.addEventListener('DOMContentLoaded', function() {
    // Gesamtübersicht Diagramm (Doughnut)
    var ctxGesamt = document.getElementById('gesamtAuslastungChart').getContext('2d');
    var gesamtChart = new Chart(ctxGesamt, {
        type: 'doughnut',
        data: {
            labels: ['Belegt', 'Frei'],
            datasets: [{
                data: [<?php echo $lagerGesamt['gesamt_belegung']; ?>, <?php echo $lagerGesamt['gesamt_kapazitaet'] - $lagerGesamt['gesamt_belegung']; ?>],
                backgroundColor: ['#007bff', '#e9ecef'],
                hoverBackgroundColor: ['#0056b3', '#ced4da'],
                borderColor: '#ffffff',
                borderWidth: 2
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: true,
            plugins: {
                legend: { position: 'bottom', labels: { font: { size: 14 } } },
                title: { display: false }
            },
            animation: {
                animateScale: true,
                animateRotate: true
            }
        }
    });

    // Top 5 Ausgelastet Diagramm (Bar)
    var ctxTop = document.getElementById('topAusgelastetChart').getContext('2d');
    var topLabels = [<?php foreach ($topAusgelastet as $lager) { echo '"' . htmlspecialchars($lager['name']) . '",'; } ?>];
    var topData = [<?php foreach ($topAusgelastet as $lager) { echo round($lager['auslastung_prozent'], 2) . ','; } ?>];

    var topChart = new Chart(ctxTop, {
        type: 'bar',
        data: {
            labels: topLabels,
            datasets: [{
                label: 'Auslastung (%)',
                data: topData,
                backgroundColor: '#ffc107',
                borderColor: '#e0a800',
                borderWidth: 1,
                hoverBackgroundColor: '#e0a800',
                hoverBorderColor: '#ffc107'
            }]
        },
        options: {
            indexAxis: 'y',
            responsive: true,
            maintainAspectRatio: true,
            plugins: {
                legend: { display: false },
                title: { display: false }
            },
            scales: {
                x: {
                    max: 100,
                    ticks: {
                        callback: function(value) {
                            return value + '%';
                        },
                        font: {
                            size: 12
                        }
                    },
                    grid: {
                        color: '#e9ecef'
                    }
                },
                y: {
                    grid: {
                        display: false
                    },
                    ticks: {
                        font: {
                            size: 12
                        }
                    }
                }
            },
            animation: {
                duration: 1000,
                easing: 'easeOutBounce'
            }
        }
    });
});
</script>

</body>
</html>
