<?php
session_start();
include 'db_connect.php';
include 'license_check.php';

// Prüfen, ob der Benutzer eingeloggt ist
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

// Gesamtstatistiken abrufen
$totalLagerplaetze = $pdo->query('SELECT SUM(kapazitaet) FROM lagerplaetze')->fetchColumn();
$totalBelegung = $pdo->query('SELECT SUM(belegung) FROM lagerplaetze')->fetchColumn();
$totalKapazitaet = $pdo->query('SELECT SUM(kapazitaet) FROM lagerplaetze')->fetchColumn();
$freieKapazitaet = $totalKapazitaet - $totalBelegung;
$durchschnittlicheAuslastung = ($totalKapazitaet > 0) ? ($totalBelegung / $totalKapazitaet) * 100 : 0;



// Aufgabenstatistiken abrufen
$totalAufgaben = $pdo->query("SELECT COUNT(*) FROM aufgaben WHERE status IN ('offen', 'in_bearbeitung')")->fetchColumn();
$letzteAufgaben = $pdo->query("SELECT * FROM aufgaben WHERE status IN ('offen', 'in_bearbeitung') ORDER BY erstellt_am DESC LIMIT 5")->fetchAll();

// Statusberichte abrufen (falls relevant)
$totalStatusberichte = $pdo->query('SELECT COUNT(*) FROM statusberichte')->fetchColumn();

// Verfügbare Ebenen abrufen
$ebenen = $pdo->query('SELECT DISTINCT ebene FROM lagerplaetze')->fetchAll(PDO::FETCH_COLUMN);

// Gewählte Ebene ermitteln
$selectedEbene = isset($_GET['ebene']) ? $_GET['ebene'] : $ebenen[0]; // Standardmäßig erste Ebene

// Daten für das Balkendiagramm vorbereiten
$lagerplatzNamen = [];
$lagerplatzAuslastung = [];

$stmt = $pdo->prepare('SELECT name, belegung, kapazitaet FROM lagerplaetze WHERE ebene = ? ORDER BY name ASC');
$stmt->execute([$selectedEbene]);
$lagerplaetze = $stmt->fetchAll();

foreach ($lagerplaetze as $row) {
    $lagerplatzNamen[] = $row['name'];
    if ($row['kapazitaet'] > 0) {
        $auslastung = ($row['belegung'] / $row['kapazitaet']) * 100;
    } else {
        $auslastung = 0; // Verhindert Division durch Null
    }
    $lagerplatzAuslastung[] = round($auslastung, 2);
}
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>SMP</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;700&display=swap" rel="stylesheet">
    <!-- Eigenes CSS -->
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            background-color: #f0f2f5;
            padding-bottom: 70px; /* Platz für die mobile Navigation */
            transition: background-color 0.5s;
        }

        /* Navbar Styling */
        .navbar {
            height: 86px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            transition: background-color 0.5s, box-shadow 0.5s;
        }

        .navbar-brand {
            font-weight: bold;
            font-size: 1.5rem;
            height: 66px;
        }

        .navbar-brand img {
            height: 100%;
            width: auto;
            object-fit: contain;
        }

        .nav-link {
            transition: color 0.3s;
        }

        .nav-link:hover, .nav-link.active {
            color: #ff6f61 !important;
        }

        /* Stat Cards */
        .stat-card {
            display: flex;
            align-items: center;
            justify-content: space-between;
            padding: 20px;
            border-radius: 15px;
            transition: transform 0.3s, box-shadow 0.3s;
            cursor: pointer;
            height: 150px; /* Feste Höhe setzen */
        }

        .stat-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 16px rgba(0,0,0,0.2);
        }

        .stat-card .icon {
            font-size: 2.5rem;
            opacity: 0.3;
            margin-left: 10px;
        }

        /* Buttons */
        .btn-custom {
            margin-right: 10px;
            border-radius: 50px;
            transition: background-color 0.3s, transform 0.3s;
        }

        .btn-custom:hover {
            transform: scale(1.05);
        }

        /* Meldungen */
        .message, .error {
            margin-top: 20px;
            padding: 15px;
            border-radius: 10px;
            display: flex;
            align-items: center;
            animation: fadeIn 0.5s ease-in-out;
        }

        .message {
            border-left: 5px solid #28a745;
            background-color: #d4edda;
            color: #155724;
        }

        .error {
            border-left: 5px solid #dc3545;
            background-color: #f8d7da;
            color: #721c24;
        }

        .message i, .error i {
            margin-right: 10px;
            font-size: 1.5rem;
        }

        /* Animation */
        @keyframes fadeIn {
            from { opacity: 0; transform: translateY(-10px); }
            to { opacity: 1; transform: translateY(0); }
        }

        /* Mobile Bottom Navigation */
        .mobile-nav {
            display: none;
        }

        @media (max-width: 767.98px) {
            .mobile-nav {
                display: flex;
                position: fixed;
                bottom: 0;
                left: 0;
                right: 0;
                background-color: #343a40;
                border-top: 1px solid #495057;
                justify-content: space-around;
                padding: 10px 0;
                z-index: 1000;
            }
            .mobile-nav a {
                color: #adb5bd;
                text-decoration: none;
                font-size: 0.85em;
                text-align: center;
                flex: 1;
                display: flex;
                flex-direction: column;
                align-items: center;
            }
            .mobile-nav a i {
                font-size: 1.5em;
                margin-bottom: 2px;
            }
            .mobile-nav a.active {
                color: #ffffff;
            }
        }

        /* Diagramme */
        .chart-container {
            position: relative;
            height: 500px;
            overflow-y: auto;
            margin-bottom: 20px;
        }

        canvas {
            background-color: #ffffff;
            border-radius: 15px;
            padding: 15px;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
            transition: transform 0.3s;
        }

        canvas:hover {
            opacity: 0.9;
            cursor: pointer;
        }

    </style>
</head>
<body>

<!-- Navigation für Desktop -->
<nav class="navbar navbar-expand-lg navbar-dark bg-dark d-none d-md-block">
  <div class="container-fluid">
    <a class="navbar-brand" href="index.php"><img src="img/logo.png" alt="Logo"></a>
    <div class="collapse navbar-collapse justify-content-end">
       <ul class="navbar-nav">
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
                 <i class="bi bi-speedometer2 me-1"></i>Dashboard
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
                 <i class="bi bi-list-task me-1"></i>Aufgaben
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
                 <i class="bi bi-box-seam me-1"></i>Lagerplätze
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="bericht.php">
                 <i class="bi bi-bar-chart-fill me-1"></i>Berichte
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
                 <i class="bi bi-gear-fill"></i>Einstellungen
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="logout.php">
                 <i class="bi bi-box-arrow-right me-1"></i>Abmelden
             </a>
         </li>
       </ul>
    </div>
  </div>
</nav>

<!-- Mobile Bottom Navigation -->
<div class="mobile-nav d-md-none">
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
        <i class="bi bi-speedometer2"></i>
        Dashboard
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
        <i class="bi bi-list-task"></i>
        Aufgaben
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
        <i class="bi bi-box-seam"></i>
        Lagerplätze
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
        <i class="bi bi-bar-chart-fill"></i>
        Berichte
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
        <i class="bi bi-gear-fill"></i>
        Einstellungen
    </a>
    <a href="logout.php">
        <i class="bi bi-box-arrow-right"></i>
        Abmelden
    </a>
</div>

<div class="container">
    <h1 class="mb-4 text-center text-primary">Willkommen, <?php echo htmlspecialchars($_SESSION['benutzername']); ?>!</h1>

    <!-- Meldungen -->
    <?php if (isset($message)): ?>
        <div class="message">
            <i class="bi bi-check-circle-fill"></i> <?php echo htmlspecialchars($message); ?>
        </div>
    <?php endif; ?>

    <?php if (!empty($errors)): ?>
        <div class="error">
            <i class="bi bi-exclamation-triangle-fill"></i>
            <?php foreach ($errors as $error): ?>
                <p><?php echo htmlspecialchars($error); ?></p>
            <?php endforeach; ?>
        </div>
    <?php endif; ?>

    <!-- Statistische Übersichtskarten -->
    <div class="row">
        <div class="col-lg-3 col-md-6 mb-4">
            <div class="card text-white bg-primary stat-card">
              <div class="card-body d-flex justify-content-between align-items-center">
                  <div>
                      <h5 class="card-title">Gesamt Lagerplätze</h5>
                      <h3 class="card-text"><?php echo $totalLagerplaetze; ?></h3>
                  </div>
                  <div class="icon"><i class="bi bi-boxes"></i></div>
              </div>
            </div>
        </div>
        <div class="col-lg-3 col-md-6 mb-4">
            <div class="card text-white bg-success stat-card">
              <div class="card-body d-flex justify-content-between align-items-center">
                  <div>
                      <h5 class="card-title">Belegte Plätze</h5>
                      <h3 class="card-text"><?php echo $totalBelegung; ?></h3>
                  </div>
                  <div class="icon"><i class="bi bi-stack"></i></div>
              </div>
            </div>
        </div>
        <div class="col-lg-3 col-md-6 mb-4">
            <div class="card text-white bg-warning stat-card">
              <div class="card-body d-flex justify-content-between align-items-center">
                  <div>
                      <h5 class="card-title">Freie Kapazität</h5>
                      <h3 class="card-text"><?php echo $freieKapazitaet; ?></h3>
                  </div>
                  <div class="icon"><i class="bi bi-bar-chart-line"></i></div>
              </div>
            </div>
        </div>
        <div class="col-lg-3 col-md-6 mb-4">
            <div class="card text-white bg-info stat-card">
              <div class="card-body d-flex justify-content-between align-items-center">
                  <div>
                      <h5 class="card-title">Durchschn. Auslastung</h5>
                      <h3 class="card-text"><?php echo round($durchschnittlicheAuslastung, 2); ?>%</h3>
                  </div>
                  <div class="icon"><i class="bi bi-graph-up"></i></div>
              </div>
            </div>
        </div>
    </div>

    <!-- Modal-Button und Modal -->
    <div class="mb-4 text-center">
        <button class="btn btn-info btn-lg shadow-sm" data-bs-toggle="modal" data-bs-target="#sehenModal">
            <i class="bi bi-search me-2"></i> Verfügbare Lagerplätze prüfen
        </button>
    </div>

    <!-- Modal -->
    <div class="modal fade" id="sehenModal" tabindex="-1" aria-labelledby="sehenModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="sehenModalLabel">Verfügbare Lagerplätze prüfen</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Schließen"></button>
                </div>
                <div class="modal-body">
                    <!-- Inhalt von sehen.php wird hier dynamisch geladen -->
                    <div id="sehenModalContent">
                        <?php include 'sehen.php'; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Aufgabenübersicht -->
    <div class="row mb-4">
        <div class="col-lg-6 mb-4">
            <div class="card shadow-sm">
                <div class="card-header bg-white border-0">
                    <h5 class="mb-0"><i class="bi bi-list-task me-2 text-primary"></i>Gesamt Aufgaben</h5>
                </div>
                <div class="card-body">
                    <h3 class="text-center text-success"><?php echo $totalAufgaben; ?></h3>
                </div>
            </div>
        </div>
        <div class="col-lg-6 mb-4">
            <div class="card shadow-sm">
                <div class="card-header bg-white border-0">
                    <h5 class="mb-0"><i class="bi bi-file-earmark-text me-2 text-secondary"></i>Statusberichte</h5>
                </div>
                <div class="card-body">
                    <h3 class="text-center text-secondary"><?php echo $totalStatusberichte; ?></h3>
                </div>
            </div>
        </div>
    </div>

    <!-- Letzte Aufgaben -->
    <div class="row mb-4">
        <div class="col-lg-6">
            <h5 class="mb-3 text-primary"><i class="bi bi-clock-history me-2"></i>Letzte Aufgaben</h5>
            <div class="table-responsive shadow-sm rounded">
                <table class="table table-hover mb-0">
                    <thead class="table-light">
                        <tr>
                            <th>Datum</th>
                            <th>Inhalt</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($letzteAufgaben as $aufgabe): ?>
                            <?php if ($aufgabe['status'] === 'offen' || $aufgabe['status'] === 'in_bearbeitung'): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars(date('d.m.Y', strtotime($aufgabe['datum']))); ?></td>
                                    <td><?php echo nl2br(htmlspecialchars($aufgabe['inhalt'])); ?></td>
                                </tr>
                            <?php endif; ?>
                        <?php endforeach; ?>
                        <?php if (empty($letzteAufgaben)): ?>
                            <tr>
                                <td colspan="2" class="text-muted text-center">Keine Aufgaben vorhanden.</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Lagerplätze mit höchster Belegung -->
        <div class="col-lg-6">
            <h5 class="mb-3 text-primary"><i class="bi bi-graph-up-arrow me-2"></i>Lagerplätze mit höchster Belegung</h5>
            <div class="table-responsive shadow-sm rounded">
                <table class="table table-hover mb-0">
                    <thead class="table-light">
                        <tr>
                            <th>Lagerplatz</th>
                            <th>Belegung</th>
                            <th>Kapazität</th>
                            <th>Auslastung (%)</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query('SELECT name, belegung, kapazitaet FROM lagerplaetze ORDER BY (belegung / kapazitaet) DESC LIMIT 5');
                        $maxRows = 5;
                        $rowCount = 0;
                        while ($row = $stmt->fetch()) {
                            $auslastung = ($row['kapazitaet'] > 0) ? ($row['belegung'] / $row['kapazitaet']) * 100 : 0;
                            echo '<tr>';
                            echo '<td>' . htmlspecialchars($row['name']) . '</td>';
                            echo '<td>' . htmlspecialchars($row['belegung']) . '</td>';
                            echo '<td>' . htmlspecialchars($row['kapazitaet']) . '</td>';
                            echo '<td>' . round($auslastung, 2) . '%</td>';
                            echo '</tr>';
                            $rowCount++;
                        }
                        // Füllen mit leeren Zeilen, falls weniger als 5 Einträge vorhanden sind
                        while ($rowCount < $maxRows) {
                            echo '<tr>';
                            echo '<td colspan="4" class="text-muted text-center">Keine weiteren Daten.</td>';
                            echo '</tr>';
                            $rowCount++;
                        }
                        ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <!-- Diagramme für Lagerplatzübersicht -->
    <div class="row mb-5">
        <!-- Donut Diagramm für Gesamtbelegung -->
        <div class="col-lg-6 mb-4">
            <div class="card shadow-sm">
                <div class="card-header bg-white border-0">
                    <h5 class="mb-0 text-primary"><i class="bi bi-pie-chart-fill me-2"></i>Gesamtbelegung der Lagerplätze</h5>
                </div>
                <div class="card-body">
                    <canvas id="gesamtBelegungDonut"></canvas>
                </div>
            </div>
        </div>
        <!-- Balkendiagramm für Auslastung je Lagerplatz -->
        <div class="col-lg-6 mb-4">
            <div class="card shadow-sm">
                <div class="card-header bg-white border-0">
                    <h5 class="mb-0 text-primary"><i class="bi bi-bar-chart-fill me-2"></i>Auslastung je Lagerplatz</h5>
                </div>
                <div class="card-body">
                    <!-- Dropdown für Ebenenauswahl -->
                    <form method="get" class="mb-3">
                        <label for="ebeneSelect" class="form-label"><strong>Ebene auswählen:</strong></label>
                        <select id="ebeneSelect" name="ebene" class="form-select" onchange="this.form.submit()">
                            <?php foreach ($ebenen as $ebene): ?>
                                <option value="<?php echo htmlspecialchars($ebene); ?>" <?php if ($ebene == $selectedEbene) echo 'selected'; ?>>
                                    <?php echo htmlspecialchars($ebene); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </form>
                    <!-- Chart Container -->
                    <div class="chart-container">
                        <canvas id="auslastungLagerplatzChart"></canvas>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Buttons zu den Modulen -->
    <div class="mb-4 text-center">
        <a href="inventur.php" class="btn btn-primary btn-lg me-3 shadow-sm">
            <i class="bi bi-clipboard-data me-2"></i>Inventur durchführen
        </a>
        <a href="kapazitaet.php" class="btn btn-secondary btn-lg shadow-sm">
            <i class="bi bi-boxes me-2"></i>Kapazität festlegen
        </a>
    </div>
</div>

<!-- Bootstrap JS und Chart.js -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Donut Diagramm - Gesamtbelegung
    var ctx1 = document.getElementById('gesamtBelegungDonut').getContext('2d');
    var gesamtBelegungDonut = new Chart(ctx1, {
        type: 'doughnut',
        data: {
            labels: ['Belegt', 'Frei'],
            datasets: [{
                data: [
                    <?php echo $totalBelegung; ?>,
                    <?php echo $freieKapazitaet; ?>
                ],
                backgroundColor: ['#4dc9f6', '#f67019'],
                hoverBackgroundColor: ['#4dc9f6', '#f67019'],
                borderColor: '#ffffff',
                borderWidth: 2
            }]
        },
        options: {
            responsive: true,
            plugins: {
                legend: { position: 'bottom', labels: { font: { size: 14 } } },
                title: { display: false }
            },
            animation: {
                animateScale: true,
                animateRotate: true
            }
        }
    });

    // Balkendiagramm - Auslastung je Lagerplatz
    var ctx3 = document.getElementById('auslastungLagerplatzChart').getContext('2d');
    var auslastungLagerplatzChart = new Chart(ctx3, {
        type: 'bar',
        data: {
            labels: <?php echo json_encode($lagerplatzNamen); ?>,
            datasets: [{
                label: 'Auslastung (%)',
                data: <?php echo json_encode($lagerplatzAuslastung); ?>,
                backgroundColor: 'rgba(75, 192, 192, 0.7)',
                borderColor: '#4bc0c0',
                borderWidth: 1,
                hoverBackgroundColor: 'rgba(75, 192, 192, 0.9)',
                hoverBorderColor: '#4bc0c0'
            }]
        },
        options: {
            indexAxis: 'y',
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: { display: false },
                title: { display: false },
                tooltip: {
                    enabled: true,
                    callbacks: {
                        title: function(context) {
                            return context[0].label;
                        },
                        label: function(context) {
                            var label = ' Auslastung: ' + context.parsed.x + '%';
                            return label;
                        }
                    }
                }
            },
            hover: {
                mode: 'nearest',
                axis: 'y',
                animationDuration: 400
            },
            scales: {
                x: {
                    beginAtZero: true,
                    max: 100,
                    ticks: {
                        callback: function(value) {
                            return value + "%";
                        },
                        font: {
                            size: 12
                        }
                    },
                    grid: {
                        display: true,
                        color: '#e9ecef'
                    }
                },
                y: {
                    ticks: {
                        font: {
                            size: 12
                        }
                    },
                    grid: {
                        display: false
                    }
                }
            },
            animation: {
                duration: 1000,
                easing: 'easeOutBounce'
            },
            layout: {
                padding: {
                    right: 30
                }
            }
        }
    });

    // Debugging: Überprüfe die Daten in der Konsole
    console.log('Labels:', <?php echo json_encode($lagerplatzNamen); ?>);
    console.log('Data:', <?php echo json_encode($lagerplatzAuslastung); ?>);
});
</script>

</body>
</html>
