<?php
// Starten Sie die Sitzung, falls noch nicht gestartet
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// Funktion zur sicheren Ausgabe von HTML
function h($string) {
    return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
}

// Bestimmen des aktuellen Installationsschritts
$step = isset($_GET['step']) ? intval($_GET['step']) : 1;

// Funktion zur Anzeige von Fortschrittsmeldungen (optional)
function show_progress($message) {
    echo '<div class="container mt-4"><div class="alert alert-info" role="alert">' . h($message) . '</div></div>';
    ob_flush();
    flush();
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Verarbeitung des Formulars für die Datenbank-Einrichtung (Schritt 2)
    if ($step === 2) {
        // MySQL-Verbindungsparameter aus dem Formular
        $host = trim($_POST['host']);
        $dbname = trim($_POST['dbname']);
        $user = trim($_POST['user']);
        $password = trim($_POST['password']);

        // Validierung der Eingaben
        $errors = [];
        if (empty($host)) {
            $errors[] = "Der Datenbank-Host darf nicht leer sein.";
        }
        if (empty($dbname)) {
            $errors[] = "Der Datenbank-Name darf nicht leer sein.";
        }
        if (empty($user)) {
            $errors[] = "Der Datenbank-Benutzername darf nicht leer sein.";
        }
        if (empty($password)) {
            $errors[] = "Das Datenbank-Passwort darf nicht leer sein.";
        }

        if (count($errors) === 0) {
            try {
                // Verbindung zur MySQL herstellen
                show_progress('Verbindung zur Datenbank wird hergestellt...');
                $pdo = new PDO("mysql:host=$host;charset=utf8mb4", $user, $password);
                $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

                // Datenbank erstellen
                show_progress('Erstelle Datenbank...');
                $pdo->exec("CREATE DATABASE IF NOT EXISTS `$dbname` CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci");
                $pdo->exec("USE `$dbname`");

                // Tabellen erstellen
                show_progress('Erstelle Tabellen...');
                $queries = [
                    // Aufgaben
                    "CREATE TABLE IF NOT EXISTS aufgaben (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        datum DATE NOT NULL,
                        inhalt TEXT NOT NULL,
                        erstellt_am DATETIME DEFAULT CURRENT_TIMESTAMP,
                        status ENUM('offen', 'in_bearbeitung', 'abgeschlossen') NOT NULL,
                        mitarbeiter_id INT NOT NULL
                    );",
                    // Auth Tokens
                    "CREATE TABLE IF NOT EXISTS auth_tokens (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        user_id INT NOT NULL,
                        token_hash VARCHAR(255) NOT NULL,
                        expires_at DATETIME NOT NULL
                    )",
                    // Failed Logins
                    "CREATE TABLE IF NOT EXISTS failed_logins (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        ip_address VARCHAR(100) NOT NULL,
                        attempted_at DATETIME NOT NULL,
                        attempts INT NOT NULL
                    )",
                    // Inventur Progress
                    "CREATE TABLE IF NOT EXISTS inventur_progress (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        mitarbeiter_id INT NOT NULL,
                        lagerplatz_id INT NOT NULL,
                        belegung INT NOT NULL,
                        completed TINYINT(1) DEFAULT 0,
                        timestamp DATETIME DEFAULT CURRENT_TIMESTAMP
                    )",
                    // Inventur Protokoll
                    "CREATE TABLE IF NOT EXISTS inventur_protokoll (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        lagerplatz_id INT NOT NULL,
                        alter_belegung INT NOT NULL,
                        neuer_belegung INT NOT NULL,
                        datum DATE NOT NULL,
                        mitarbeiter_id INT NOT NULL
                    )",
                    // Kapazität Progress
                    "CREATE TABLE IF NOT EXISTS kapazitaet_progress (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        mitarbeiter_id INT NOT NULL,
                        lagerplatz_id INT NOT NULL,
                        kapazitaet INT NOT NULL,
                        completed TINYINT(1) DEFAULT 0,
                        timestamp DATETIME DEFAULT CURRENT_TIMESTAMP
                    )",
                    // Kapazität Protokoll
                    "CREATE TABLE IF NOT EXISTS kapazitaet_protokoll (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        lagerplatz_id INT NOT NULL,
                        alte_kapazitaet INT NOT NULL,
                        neue_kapazitaet INT NOT NULL,
                        datum DATE NOT NULL,
                        mitarbeiter_id INT NOT NULL
                    )",
                    // Lagerplätze
                    "CREATE TABLE IF NOT EXISTS lagerplaetze (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        name VARCHAR(100) NOT NULL,
                        standort TEXT NOT NULL,
                        beschreibung TEXT,
                        kapazitaet INT NOT NULL,
                        belegung INT DEFAULT 0,
                        ebene TEXT
                    )",
                    // Login Logs
                    "CREATE TABLE IF NOT EXISTS login_logs (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        user_id INT NOT NULL,
                        ip_address VARCHAR(100) NOT NULL,
                        login_time DATETIME DEFAULT CURRENT_TIMESTAMP,
                        success TINYINT(1) NOT NULL
                    )",
                    // Mitarbeiter
                    "CREATE TABLE IF NOT EXISTS mitarbeiter (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        name VARCHAR(100) NOT NULL,
                        email VARCHAR(255) NOT NULL UNIQUE,
                        benutzername VARCHAR(50) NOT NULL UNIQUE,
                        passwort VARCHAR(255) NOT NULL,
                        rolle VARCHAR(50) DEFAULT 'Mitarbeiter',
                        session_id VARCHAR(255) DEFAULT NULL
                    )",
                    // Settings
                    "CREATE TABLE IF NOT EXISTS settings (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        key_name VARCHAR(100) NOT NULL UNIQUE,
                        value TEXT,
                        description TEXT,
                        created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
                        updated_at DATETIME ON UPDATE CURRENT_TIMESTAMP DEFAULT CURRENT_TIMESTAMP
                    )",

                    // Initialer Eintrag für die Version
                    "INSERT IGNORE INTO settings (key_name, value, description, created_at, updated_at) 
                    VALUES ('version', '1.7', 'Systemversion der SMP-Software', NOW(), NOW());", // <-- Komma hinzugefügt

                    // Statusberichte
                    "CREATE TABLE IF NOT EXISTS statusberichte (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        lagerplatz_id INT NOT NULL,
                        aufgabe_id INT NOT NULL,
                        statuswert VARCHAR(100) NOT NULL,
                        bemerkungen TEXT
                    )"

                ];

                foreach ($queries as $query) {
                    $pdo->exec($query);
                }

                // Initiale Daten einfügen
                show_progress('Füge initiale Daten ein...');
                $adminPasswordHash = password_hash('admin', PASSWORD_BCRYPT);
                $stmt = $pdo->prepare("INSERT INTO mitarbeiter (name, email, benutzername, passwort, rolle) VALUES (:name, :email, :benutzername, :passwort, :rolle)");
                $stmt->execute([
                    ':name' => 'Administrator',
                    ':email' => 'admin@example.com',
                    ':benutzername' => 'admin',
                    ':passwort' => $adminPasswordHash,
                    ':rolle' => 'Admin'
                ]);

                // Einträge in die Tabelle 'settings' ohne 'license_key' und 'license_data'
                show_progress('Füge Einstellungen ein...');
                $stmt = $pdo->prepare("INSERT INTO settings (key_name, value, description) VALUES (:key_name, :value, :description)");
                $settings = [
                    ['lagerplatz_ebenen', NULL, 'Lagerplatz-Ebenen'],
                    ['lagerplatz_mapping', NULL, 'Zuordnung der Produkttypen zu Lagerplatz-Ebenen']
                ];
                foreach ($settings as $setting) {
                    $stmt->execute([
                        ':key_name' => $setting[0],
                        ':value' => $setting[1],
                        ':description' => $setting[2]
                    ]);
                }

                // `db_connect.php` erstellen
                show_progress('Erstelle db_connect.php...');
                $dbConnectContent = <<<PHP
<?php
\$host = '$host';
\$db = '$dbname';
\$user = '$user';
\$pass = '$password';
\$charset = 'utf8mb4';

\$dsn = "mysql:host=\$host;dbname=\$db;charset=\$charset";
\$options = [
    PDO::ATTR_ERRMODE            => PDO::ERRMODE_EXCEPTION,
    PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
];

try {
     \$pdo = new PDO(\$dsn, \$user, \$pass, \$options);
} catch (\\PDOException \$e) {
     throw new \\PDOException(\$e->getMessage(), (int)\$e->getCode());
}
?>
PHP;

                if (file_put_contents('db_connect.php', $dbConnectContent) === false) {
                    throw new Exception('Fehler beim Erstellen der db_connect.php-Datei. Bitte überprüfen Sie die Dateiberechtigungen.');
                }

                // Erfolgreiche Installation anzeigen
                ?>
                <!DOCTYPE html>
                <html lang="de">
                <head>
                    <meta charset="UTF-8">
                    <title>Installation abgeschlossen - LagerLogistikPro</title>
                    <!-- Bootstrap CSS -->
                    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
                    <!-- Custom CSS -->
                    <style>
                        body {
                            background-color: #f7f9fc;
                        }
                        .container {
                            max-width: 700px;
                            margin-top: 50px;
                            text-align: center;
                        }
                        .success-message {
                            background-color: #ffffff;
                            padding: 40px;
                            border-radius: 8px;
                            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
                        }
                        .success-message h1 {
                            font-size: 2rem;
                            margin-bottom: 20px;
                            color: #28a745;
                        }
                        .success-message p {
                            font-size: 1.1rem;
                            color: #555;
                        }
                        .success-message a {
                            margin-top: 20px;
                        }
                    </style>
                </head>
                <body>
                <div class="container">
                    <div class="success-message">
                        <h1>Installation erfolgreich!</h1>
                        <p>LagerLogistikPro wurde erfolgreich installiert.</p>
                        <hr>
                        <h4>Standard-Login-Daten:</h4>
                        <p>Benutzername: <strong>admin</strong></p>
                        <p>Passwort: <strong>admin</strong></p>
                        <p>Bitte ändern Sie das Passwort nach dem ersten Login, um die Sicherheit zu gewährleisten.</p>
                        <a href="login.php" class="btn btn-success w-100">Zum Login</a>
                        <hr>
                        <p>Die Installationsdatei <strong>install.php</strong> wurde automatisch gelöscht, um die Sicherheit zu gewährleisten.</p>
                        <p>Falls die Datei nicht gelöscht wurde, löschen Sie sie bitte manuell.</p>
                    </div>
                </div>
                </body>
                </html>
                <?php

                // Hier wird die install.php-Datei automatisch gelöscht
                if (!unlink(__FILE__)) {
                    // Falls das Löschen fehlschlägt, informieren Sie den Benutzer
                    echo '<div class="container mt-4"><div class="alert alert-warning" role="alert">
                            Die Installationsdatei <strong>install.php</strong> konnte nicht automatisch gelöscht werden. Bitte löschen Sie die Datei manuell, um die Sicherheit zu gewährleisten.
                          </div></div>';
                }

                exit;

            } catch (PDOException $e) {
                // Fehlermeldung anzeigen
                $errors[] = "Datenbankfehler: " . $e->getMessage();
            } catch (Exception $e) {
                // Allgemeine Fehlermeldung anzeigen
                $errors[] = "Fehler: " . $e->getMessage();
            }
        }

        // Bei Fehlern zum Schritt 2 zurückkehren und Fehler anzeigen
        if (count($errors) > 0) {
            $_SESSION['errors'] = $errors;
            // Speichern der eingegebenen Daten, um sie nicht erneut eingeben zu müssen
            $_SESSION['form_data'] = [
                'host' => $host,
                'dbname' => $dbname,
                'user' => $user,
                'password' => $password
            ];
            header("Location: install.php?step=2");
            exit;
        }
    }
}

// Anzeige der jeweiligen Installationsschritte
switch ($step) {
    case 1:
        // Schritt 1: Willkommensbildschirm mit Systemanforderungen
        ?>
        <!DOCTYPE html>
        <html lang="de">
        <head>
            <meta charset="UTF-8">
            <title>Willkommen zur Installation - LagerLogistikPro</title>
            <!-- Bootstrap CSS -->
            <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
            <!-- Custom CSS -->
            <style>
                body {
                    background-color: #f7f9fc;
                }
                .container {
                    max-width: 700px;
                    margin-top: 50px;
                }
                .welcome-message, .requirements, .next-step {
                    background-color: #ffffff;
                    padding: 30px;
                    border-radius: 8px;
                    box-shadow: 0 4px 6px rgba(0,0,0,0.1);
                    margin-bottom: 20px;
                }
                .next-step a {
                    margin-top: 20px;
                }
            </style>
        </head>
        <body>
        <div class="container">
            <div class="welcome-message">
                <h1 class="mb-4">Willkommen zur SMP Installation</h1>
                <p>Vielen Dank, dass Sie sich für unsere Software entschieden haben. Dieser Installationsassistent führt Sie durch die Einrichtung Ihrer neuen Lagerverwaltungssoftware.</p>
            </div>

            <div class="requirements">
                <h4>Systemanforderungen:</h4>
                <ul class="list-group list-group-flush">
                    <li class="list-group-item"><strong>Webserver:</strong> Apache oder ein anderer kompatibler Webserver im privaten Netzwerk.</li>
                    <li class="list-group-item"><strong>PHP:</strong> Version 7.4 oder höher mit folgenden Erweiterungen:
                        <ul>
                            <li>PDO</li>
                            <li>pdo_mysql</li>
                            <li>mbstring</li>
                            <li>openssl</li>
                            <li>json</li>
                            <li>ctype</li>
                            <li>tokenizer</li>
                            <li>xml</li>
                        </ul>
                    </li>
                    <li class="list-group-item"><strong>MySQL:</strong> Version 5.7 oder höher für die Datenbankverwaltung.</li>
                    <li class="list-group-item"><strong>Dateiberechtigungen:</strong> Schreibrechte für das Installationsverzeichnis.</li>
                </ul>
                <p class="mt-3">Bitte stellen Sie sicher, dass Ihr System alle oben genannten Anforderungen erfüllt, bevor Sie mit der Installation fortfahren.</p>
            </div>

            <div class="next-step text-center">
                <a href="install.php?step=2" class="btn btn-primary">Weiter zur Datenbank-Einrichtung</a>
            </div>
        </div>
        </body>
        </html>
        <?php
        break;

    case 2:
        // Schritt 2: Datenbank-Einrichtung
        // Abrufen von Fehlern und vorherigen Formulardaten aus der Sitzung
        $errors = isset($_SESSION['errors']) ? $_SESSION['errors'] : [];
        $form_data = isset($_SESSION['form_data']) ? $_SESSION['form_data'] : ['host' => '', 'dbname' => '', 'user' => '', 'password' => ''];

        // Löschen der Fehler und Formulardaten aus der Sitzung
        unset($_SESSION['errors']);
        unset($_SESSION['form_data']);
        ?>
        <!DOCTYPE html>
        <html lang="de">
        <head>
            <meta charset="UTF-8">
            <title>Datenbank-Einrichtung - SMP</title>
            <!-- Bootstrap CSS -->
            <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
            <!-- Custom CSS -->
            <style>
                body {
                    background-color: #f7f9fc;
                }
                .container {
                    max-width: 700px;
                    margin-top: 50px;
                }
                .install-form, .error-messages {
                    background-color: #ffffff;
                    padding: 30px;
                    border-radius: 8px;
                    box-shadow: 0 4px 6px rgba(0,0,0,0.1);
                    margin-bottom: 20px;
                }
                .form-label {
                    font-weight: bold;
                }
                .tooltip-inner {
                    max-width: 300px;
                    /* If max-width does not work, try using width instead */
                    width: 300px; 
                }
            </style>
        </head>
        <body>
        <div class="container">
            <?php if (count($errors) > 0): ?>
                <div class="error-messages">
                    <div class="alert alert-danger" role="alert">
                        <h4 class="alert-heading">Fehler bei der Installation!</h4>
                        <ul>
                            <?php foreach ($errors as $error): ?>
                                <li><?php echo h($error); ?></li>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                </div>
            <?php endif; ?>

            <div class="install-form">
                <h2 class="text-center mb-4">Schritt 2: Datenbank-Einrichtung</h2>
                <p>Bitte geben Sie die erforderlichen Datenbankinformationen ein. Falls Sie sich nicht sicher sind, wenden Sie sich an Ihren Hosting-Anbieter oder Systemadministrator.</p>
                <form method="POST" action="install.php?step=2" class="needs-validation" novalidate>
                    <div class="mb-3">
                        <label for="host" class="form-label">Datenbank-Host <span data-bs-toggle="tooltip" data-bs-placement="right" title="In der Regel ist dies 'localhost'. Wenn Sie sich nicht sicher sind, fragen Sie Ihren Hosting-Anbieter.">[?]</span></label>
                        <input type="text" id="host" name="host" class="form-control" placeholder="z. B. localhost" value="<?php echo h($form_data['host']); ?>" required>
                        <div class="invalid-feedback">
                            Bitte geben Sie den Datenbank-Host ein.
                        </div>
                    </div>
                    <div class="mb-3">
                        <label for="dbname" class="form-label">Datenbank-Name <span data-bs-toggle="tooltip" data-bs-placement="right" title="Der Name der Datenbank, die für LagerLogistikPro verwendet wird.">[?]</span></label>
                        <input type="text" id="dbname" name="dbname" class="form-control" placeholder="Name der Datenbank" value="<?php echo h($form_data['dbname']); ?>" required>
                        <div class="invalid-feedback">
                            Bitte geben Sie den Datenbank-Namen ein.
                        </div>
                    </div>
                    <div class="mb-3">
                        <label for="user" class="form-label">Datenbank-Benutzername <span data-bs-toggle="tooltip" data-bs-placement="right" title="Der Benutzername für den Datenbankzugriff.">[?]</span></label>
                        <input type="text" id="user" name="user" class="form-control" placeholder="Datenbank-Benutzername" value="<?php echo h($form_data['user']); ?>" required>
                        <div class="invalid-feedback">
                            Bitte geben Sie den Datenbank-Benutzernamen ein.
                        </div>
                    </div>
                    <div class="mb-3">
                        <label for="password" class="form-label">Datenbank-Passwort <span data-bs-toggle="tooltip" data-bs-placement="right" title="Das Passwort für den Datenbankbenutzer.">[?]</span></label>
                        <input type="password" id="password" name="password" class="form-control" placeholder="Datenbank-Passwort" value="<?php echo h($form_data['password']); ?>" required>
                        <div class="invalid-feedback">
                            Bitte geben Sie das Datenbank-Passwort ein.
                        </div>
                    </div>
                    <button type="submit" class="btn btn-primary w-100">Installation starten</button>
                </form>
            </div>
        </div>

        <!-- Bootstrap JS and dependencies (Popper.js) -->
        <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js" integrity="sha384-zxjIBkJk1WfIzYfC+nlN1B4lqPFkZUnCAheHzg8Ph4pV68RvX1bE+3D8j9NsL6Rb" crossorigin="anonymous"></script>
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
        <!-- Custom JS for form validation and tooltips -->
        <script>
            // Enable tooltips
            var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'))
            var tooltipList = tooltipTriggerList.map(function (tooltipTriggerEl) {
              return new bootstrap.Tooltip(tooltipTriggerEl)
            })

            // Bootstrap form validation
            (function () {
                'use strict'
                var forms = document.querySelectorAll('.needs-validation')
                Array.prototype.slice.call(forms)
                    .forEach(function (form) {
                        form.addEventListener('submit', function (event) {
                            if (!form.checkValidity()) {
                                event.preventDefault()
                                event.stopPropagation()
                            }
                            form.classList.add('was-validated')
                        }, false)
                    })
            })()
        </script>
        </body>
        </html>
        <?php
        break;

    default:
        // Ungültiger Schritt, zurück zum ersten Schritt
        header("Location: install.php?step=1");
        exit;
}
?>
