<?php
include 'db_connect.php';
session_start();

// Überprüfung, ob der Benutzer eingeloggt ist und die Rolle „Admin“ hat
$isAdmin = isset($_SESSION['rolle']) && $_SESSION['rolle'] === 'Admin';

try {
    // Anzahl der Elemente pro Anfrage
    $itemsPerPage = isset($_GET['limit']) ? (int)$_GET['limit'] : 20;

    // Parameter abrufen
    $offset = isset($_GET['offset']) ? (int)$_GET['offset'] : 0;
    $filterEbenen = isset($_GET['ebenen']) ? $_GET['ebenen'] : [];
    $searchTerm = isset($_GET['search']) ? $_GET['search'] : '';

    // Ebenen aus den Einstellungen laden
    $stmt = $pdo->prepare('SELECT value FROM settings WHERE key_name = "lagerplatz_ebenen" LIMIT 1');
    $stmt->execute();
    $ebenenSetting = $stmt->fetch();
    $lagerplatz_ebenen = $ebenenSetting ? json_decode($ebenenSetting['value'], true) : [];

    // Extrahieren der Kürzel in der definierten Reihenfolge
    $ebenen_order = array_map(function($ebene) {
        return $ebene['kurzel'];
    }, $lagerplatz_ebenen);

    // Build query
    $query = 'SELECT * FROM lagerplaetze WHERE 1=1';
    $params = [];

    // Filter by Ebenen
    if (!empty($filterEbenen)) {
        $inQuery = implode(',', array_fill(0, count($filterEbenen), '?'));
        $query .= ' AND ebene IN (' . $inQuery . ')';
        $params = array_merge($params, $filterEbenen);
    }

    // Search term
    if (!empty($searchTerm)) {
        $query .= ' AND (LOWER(name) LIKE ? OR LOWER(standort) LIKE ?)';
        $searchTermWildcard = '%' . strtolower($searchTerm) . '%';
        $params[] = $searchTermWildcard;
        $params[] = $searchTermWildcard;
    }

    // ORDER BY-Klausel erstellen
    if (!empty($ebenen_order)) {
        $orderByClause = ' ORDER BY FIELD(ebene';
        foreach ($ebenen_order as $ebene_kurzel) {
            $orderByClause .= ', ' . $pdo->quote($ebene_kurzel);
        }
        $orderByClause .= '), name';
    } else {
        $orderByClause = ' ORDER BY name';
    }

    // Add limit and offset directly into the query
    $query .= $orderByClause . ' LIMIT ' . $itemsPerPage . ' OFFSET ' . $offset;

    // Prepare and execute
    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $lagerplaetze = $stmt->fetchAll();

    // Generate HTML
    foreach ($lagerplaetze as $lagerplatz):
        $kapazitaet = $lagerplatz['kapazitaet'];
        $belegung = $lagerplatz['belegung'];
        $auslastung = ($kapazitaet > 0) ? ($belegung / $kapazitaet) * 100 : 0;

        // Bestimmung der Progress-Bar-Farbe
        if ($auslastung < 50) {
            $color = 'green';
        } elseif ($auslastung < 80) {
            $color = 'yellow';
        } else {
            $color = 'red';
        }
    ?>
    <div class="col-lg-4 col-md-6 col-sm-12 lagerplatz-card" id="lagerplatz_<?php echo $lagerplatz['id']; ?>" 
         data-name="<?php echo htmlspecialchars(strtolower($lagerplatz['name'])); ?>" 
         data-standort="<?php echo htmlspecialchars(strtolower($lagerplatz['standort'])); ?>" 
         data-ebene="<?php echo htmlspecialchars(strtolower($lagerplatz['ebene'])); ?>">
        <div class="card h-100">
            <div class="card-header">
                <i class="bi bi-box-seam"></i>
                <?php echo htmlspecialchars($lagerplatz['name']); ?>
            </div>
            <div class="card-body d-flex flex-column">
                <ul>
                    <li><i class="bi bi-geo-alt-fill"></i><strong> Standort:</strong> <?php echo htmlspecialchars($lagerplatz['standort']); ?></li>
                    <?php if (!empty($lagerplatz['beschreibung'])): ?>
                    <li><i class="bi bi-card-text"></i><strong> Beschreibung:</strong> <?php echo htmlspecialchars($lagerplatz['beschreibung']); ?></li>
                    <?php endif; ?>
                    <li><i class="bi bi-layers-fill"></i><strong> Ebene:</strong> <?php echo htmlspecialchars($lagerplatz['ebene']); ?></li>
                    <li><i class="bi bi-stack"></i><strong> Kapazität:</strong> <?php echo htmlspecialchars($kapazitaet); ?></li>
                    <li><i class="bi bi-boxes"></i><strong> Belegung:</strong> <?php echo htmlspecialchars($belegung); ?></li>
                </ul>
                <div class="mt-auto">
                    <p class="mb-1"><strong>Auslastung:</strong></p>
                    <div class="progress mb-2">
                        <div class="progress-bar <?php echo $color; ?>" role="progressbar" style="width: <?php echo $auslastung; ?>%;" aria-valuenow="<?php echo $auslastung; ?>" aria-valuemin="0" aria-valuemax="100"><?php echo round($auslastung, 2); ?>%</div>
                    </div>
                    <?php if ($isAdmin): ?>
                    <div class="d-flex justify-content-between mt-3">
                        <button class="btn btn-sm btn-outline-primary" data-bs-toggle="modal" data-bs-target="#editModal_<?php echo $lagerplatz['id']; ?>"><i class="bi bi-pencil-square me-1"></i>Bearbeiten</button>
                        <form action="lagerplaetze.php" method="POST" onsubmit="return confirm('Sind Sie sicher, dass Sie diesen Lagerplatz löschen möchten?');">
                            <input type="hidden" name="lagerplatz_id" value="<?php echo $lagerplatz['id']; ?>">
                            <button type="submit" name="deleteLagerplatz" class="btn btn-sm btn-outline-danger"><i class="bi bi-trash me-1"></i>Löschen</button>
                        </form>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>

    <!-- Bearbeiten Modal -->
    <?php if ($isAdmin): ?>
    <div class="modal fade" id="editModal_<?php echo $lagerplatz['id']; ?>" tabindex="-1" aria-labelledby="editModalLabel_<?php echo $lagerplatz['id']; ?>" aria-hidden="true">
      <div class="modal-dialog">
        <div class="modal-content">
          <form action="lagerplaetze.php" method="POST">
              <div class="modal-header">
                <h5 class="modal-title" id="editModalLabel_<?php echo $lagerplatz['id']; ?>"><i class="bi bi-pencil-square me-2"></i>Lagerplatz bearbeiten - <?php echo htmlspecialchars($lagerplatz['name']); ?></h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Schließen"></button>
              </div>
              <div class="modal-body">
                  <input type="hidden" name="lagerplatz_id" value="<?php echo $lagerplatz['id']; ?>">
                  <div class="mb-3">
                      <label>Belegung</label>
                      <input type="number" name="belegung" value="<?php echo htmlspecialchars($belegung); ?>" min="0" max="<?php echo htmlspecialchars($kapazitaet); ?>" class="form-control" required>
                  </div>
                  <div class="mb-3">
                      <label>Kapazität</label>
                      <input type="number" name="kapazitaet" value="<?php echo htmlspecialchars($kapazitaet); ?>" class="form-control" required>
                  </div>
                  <div class="mb-3">
                      <label>Beschreibung</label>
                      <textarea name="beschreibung" class="form-control" rows="3"><?php echo htmlspecialchars($lagerplatz['beschreibung']); ?></textarea>
                  </div>
              </div>
              <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Abbrechen</button>
                <button type="submit" name="updateLagerplatz" class="btn btn-success"><i class="bi bi-save me-1"></i>Speichern</button>
              </div>
          </form>
        </div>
      </div>
    </div>
    <?php endif; ?>

    <?php endforeach; ?>

<?php
} catch (PDOException $e) {
    echo "Datenbankfehler: " . $e->getMessage();
    exit();
}
?>
