<?php
session_start();
include 'license_check.php';
include 'db_connect.php';

// Überprüfung, ob der Benutzer angemeldet ist
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

// Nachrichtenspeicher
$message = "";

// Aktuelle Version aus der Datenbank abrufen
$currentVersion = 'Unbekannt';
try {
    $stmt = $pdo->prepare("SELECT value FROM settings WHERE key_name = 'version'");
    $stmt->execute();
    $currentVersion = $stmt->fetchColumn() ?: 'Unbekannt';
} catch (PDOException $e) {
    $message = "Fehler beim Abrufen der aktuellen Version: " . $e->getMessage();
}

// Funktion zur sicheren Extraktion der ZIP-Datei
function extractZip($zipPath, $extractTo) {
    $zip = new ZipArchive;
    if ($zip->open($zipPath) === TRUE) {
        $zip->extractTo($extractTo);
        $zip->close();
        return true;
    } else {
        return false;
    }
}

// Funktion zur Überprüfung der Standardstruktur
function hasStandardStructure($extractedPath) {
    $versionDirs = glob($extractedPath . '/*', GLOB_ONLYDIR);
    if (count($versionDirs) == 0) {
        return false;
    }
    
    foreach ($versionDirs as $versionDir) {
        $neuInstallation = $versionDir . '/NEU INSTALLATION';
        $readme = $versionDir . '/readme.docx';
        $updateZip = $versionDir . '/UPDATE.zip';
        $versionInfo = $versionDir . '/version_info.json';
        
        if (is_dir($neuInstallation) && file_exists($readme) && file_exists($updateZip) && file_exists($versionInfo)) {
            return [
                'versionDir' => $versionDir,
                'neuInstallation' => $neuInstallation,
                'updateZip' => $updateZip,
                'versionInfo' => $versionInfo
            ];
        }
    }
    return false;
}

// Funktion zum Entfernen von Verzeichnissen
function deleteDir($dirPath) {
    if (!is_dir($dirPath)) {
        return;
    }
    $objects = scandir($dirPath);
    foreach ($objects as $object) {
        if ($object != "." && $object != "..") {
            if (is_dir($dirPath . "/" . $object)) {
                deleteDir($dirPath . "/" . $object);
            } else {
                unlink($dirPath . "/" . $object);
            }
        }
    }
    rmdir($dirPath);
}

// Funktion zum rekursiven Kopieren von Dateien
function copyFiles($source, $dest) {
    $dir = opendir($source);
    @mkdir($dest, 0755, true);
    while(false !== ($file = readdir($dir))) {
        if (($file != '.') && ($file != '..')) {
            if (is_dir($source . '/' . $file)) {
                copyFiles($source . '/' . $file, $dest . '/' . $file);
            } else {
                // Sicherstellen, dass das Zielverzeichnis existiert
                $targetDir = dirname($dest . '/' . $file);
                if (!is_dir($targetDir)) {
                    mkdir($targetDir, 0755, true);
                }
                copy($source . '/' . $file, $dest . '/' . $file);
            }
        }
    }
    closedir($dir);
}

// Schritt 1: Upload der ZIP-Datei
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['step']) && $_POST['step'] == 'upload') {
    if (isset($_FILES['update_zip']) && $_FILES['update_zip']['error'] === UPLOAD_ERR_OK) {
        $fileTmpPath = $_FILES['update_zip']['tmp_name'];
        $fileName = $_FILES['update_zip']['name'];
        $fileSize = $_FILES['update_zip']['size'];
        $fileType = $_FILES['update_zip']['type'];
        $fileNameCmps = explode(".", $fileName);
        $fileExtension = strtolower(end($fileNameCmps));

        // Überprüfen der Dateiendung
        if ($fileExtension !== 'zip') {
            $message = "Nur ZIP-Dateien sind erlaubt.";
        } elseif ($fileSize > 50 * 1024 * 1024) { // 50MB Limit
            $message = "Die Datei ist zu groß. Maximal 50MB erlaubt.";
        } else {
            // Temporäres Verzeichnis für die Extraktion
            $tempDir = sys_get_temp_dir() . '/update_' . uniqid();
            if (!mkdir($tempDir, 0755, true)) {
                $message = "Fehler beim Erstellen des temporären Verzeichnisses.";
            } else {
                // Verschieben der hochgeladenen Datei in das temporäre Verzeichnis
                $destPath = $tempDir . '/' . $fileName;
                if (move_uploaded_file($fileTmpPath, $destPath)) {
                    // Extrahieren der ZIP-Datei
                    if (extractZip($destPath, $tempDir)) {
                        // Überprüfen der Struktur
                        $structure = hasStandardStructure($tempDir);
                        if ($structure) {
                            // Speichern der Struktur in der Session für den nächsten Schritt
                            $_SESSION['update_structure'] = $structure;
                            $_SESSION['temp_dir'] = $tempDir;
                            $_SESSION['uploaded_zip'] = $destPath;
                            // Weiter zum Auswahlformular
                            header('Location: update.php?step=choose');
                            exit();
                        } else {
                            // Überprüfen, ob nur UPDATE.zip vorhanden ist
                            $updateZips = glob($tempDir . '/UPDATE.zip');
                            $versionInfos = glob($tempDir . '/version_info.json');
                            if (count($updateZips) == 1 && count($versionInfos) == 1) {
                                $_SESSION['update_only_zip'] = $updateZips[0];
                                $_SESSION['version_info'] = $versionInfos[0];
                                $_SESSION['temp_dir'] = $tempDir;
                                $_SESSION['uploaded_zip'] = $destPath;
                                // Automatisches Update durchführen
                                header('Location: update.php?step=perform_update');
                                exit();
                            } else {
                                $message = "Die ZIP-Datei hat keine gültige Struktur. Bitte stellen Sie sicher, dass sie die erwarteten Ordner und Dateien enthält.";
                                // Bereinigung
                                unlink($destPath);
                                deleteDir($tempDir);
                            }
                        }
                    } else {
                        $message = "Fehler beim Extrahieren der ZIP-Datei.";
                        // Bereinigung
                        unlink($destPath);
                        deleteDir($tempDir);
                    }
                } else {
                    $message = "Fehler beim Verschieben der hochgeladenen Datei.";
                    deleteDir($tempDir);
                }
            }
        }
    } else {
        $message = "Fehler beim Hochladen der Datei.";
    }
}

// Schritt 2: Auswahl zwischen Update und frischer Installation
if (isset($_GET['step']) && $_GET['step'] == 'choose' && isset($_SESSION['update_structure'])) {
    // Anzeige des Auswahlformulars
    ?>
    <!DOCTYPE html>
    <html lang="de">
    <head>
        <meta charset="UTF-8">
        <title>Update oder Installation wählen</title>
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <!-- Bootstrap CSS -->
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">
        <style>
            body {
                background-color: #f8f9fa;
                font-family: 'Roboto', sans-serif;
                padding-top: 50px;
            }
            .container {
                max-width: 600px;
            }
            .note {
                background-color: #fff3cd;
                border: 1px solid #ffeeba;
                padding: 15px;
                border-radius: 5px;
                margin-bottom: 20px;
            }
        </style>
    </head>
    <body>
    
    <div class="container">
        <h2 class="mb-4 text-center">Update oder frische Installation</h2>
        <?php if (!empty($message)): ?>
            <div class="alert alert-danger text-center"><?php echo htmlspecialchars($message); ?></div>
        <?php endif; ?>
        <div class="note">
            <strong>Hinweis:</strong> Dieser Schritt kann nicht rückgängig gemacht werden. Stellen Sie sicher, dass Sie ein Backup Ihrer Daten haben, bevor Sie fortfahren.
        </div>
        <form method="POST" action="update.php">
            <input type="hidden" name="step" value="choose_action">
            <div class="mb-3">
                <label class="form-label">Möchten Sie ein Update auf die neue Version vornehmen oder eine frische Installation starten?</label>
                <div>
                    <div class="form-check">
                        <input class="form-check-input" type="radio" name="action" id="update" value="update" required>
                        <label class="form-check-label" for="update">
                            Update auf die neue Version
                        </label>
                    </div>
                    <div class="form-check">
                        <input class="form-check-input" type="radio" name="action" id="fresh_install" value="fresh_install" required>
                        <label class="form-check-label" for="fresh_install">
                            Frische Installation
                        </label>
                    </div>
                </div>
            </div>
            <button type="submit" class="btn btn-primary w-100">Weiter</button>
        </form>
    </div>
    
    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    </body>
    </html>
    <?php
    exit();
}

// Schritt 3: Verarbeitung der Auswahl (Update oder frische Installation)
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['step']) && $_POST['step'] == 'choose_action' && isset($_SESSION['update_structure'])) {
    $action = $_POST['action'];
    $structure = $_SESSION['update_structure'];
    $tempDir = $_SESSION['temp_dir'];
    $uploadedZip = $_SESSION['uploaded_zip'];

    if ($action == 'update') {
        // Update durchführen
        $updateZipPath = $structure['updateZip'];
        $versionInfoPath = $structure['versionInfo']; // Korrigierter Pfad
        $updateExtractPath = $tempDir . '/update_extracted';
        if (!mkdir($updateExtractPath, 0755, true)) {
            $message = "Fehler beim Erstellen des Update-Verzeichnisses.";
        } else {
            if (extractZip($updateZipPath, $updateExtractPath)) {
                // Kopieren der Dateien aus UPDATE.zip in das Hauptverzeichnis
                $sourceDir = $updateExtractPath;
                $destDir = __DIR__; // Hauptverzeichnis der Anwendung

                copyFiles($sourceDir, $destDir);

                // Lesen der Version aus der version_info.json
                if (file_exists($versionInfoPath)) {
                    $versionData = json_decode(file_get_contents($versionInfoPath), true);
                    if (isset($versionData['version'])) {
                        $newVersion = $versionData['version'];

                        // Version in die Datenbank aktualisieren
                        try {
                            $stmt = $pdo->prepare("SELECT COUNT(*) FROM settings WHERE key_name = 'version'");
                            $stmt->execute();
                            $exists = $stmt->fetchColumn();

                            if ($exists) {
                                $stmt = $pdo->prepare("UPDATE settings SET value = :version, updated_at = NOW() WHERE key_name = 'version'");
                            } else {
                                $stmt = $pdo->prepare("INSERT INTO settings (key_name, value, description, created_at, updated_at)
                                    VALUES ('version', :version, 'Aktuelle SMP-Softwareversion', NOW(), NOW())");
                            }

                            $stmt->execute([':version' => $newVersion]);
                            $currentVersion = $newVersion;
                            $message = "Update erfolgreich abgeschlossen! Neue Version: $newVersion.";
                        } catch (PDOException $e) {
                            $message = "Datenbankfehler: " . $e->getMessage();
                        }
                    } else {
                        $message = "Fehler: version_info.json enthält keine gültige Versionsnummer.";
                    }
                } else {
                    $message = "Fehler: version_info.json konnte nicht gefunden werden.";
                }
            } else {
                $message = "Fehler beim Extrahieren der UPDATE.zip-Datei.";
            }
        }
    } elseif ($action == 'fresh_install') {
        // Frische Installation durchführen
        $neuInstallationPath = $structure['neuInstallation'];
        $versionInfoPath = $structure['versionInfo']; // Annahme: version_info.json ist ebenfalls im NEU INSTALLATION Ordner
        $installExtractPath = $tempDir . '/install_extracted';
        if (!mkdir($installExtractPath, 0755, true)) {
            $message = "Fehler beim Erstellen des Installations-Verzeichnisses.";
        } else {
            if (extractZip($neuInstallationPath, $installExtractPath)) {
                // Kopieren der Dateien aus NEU INSTALLATION in das Hauptverzeichnis
                $sourceDir = $installExtractPath;
                $destDir = __DIR__; // Hauptverzeichnis der Anwendung

                copyFiles($sourceDir, $destDir);

                // Lesen der Version aus der version_info.json
                if (file_exists($versionInfoPath)) {
                    $versionData = json_decode(file_get_contents($versionInfoPath), true);
                    if (isset($versionData['version'])) {
                        $newVersion = $versionData['version'];

                        // Version in die Datenbank aktualisieren
                        try {
                            $stmt = $pdo->prepare("SELECT COUNT(*) FROM settings WHERE key_name = 'version'");
                            $stmt->execute();
                            $exists = $stmt->fetchColumn();

                            if ($exists) {
                                $stmt = $pdo->prepare("UPDATE settings SET value = :version, updated_at = NOW() WHERE key_name = 'version'");
                            } else {
                                $stmt = $pdo->prepare("INSERT INTO settings (key_name, value, description, created_at, updated_at)
                                    VALUES ('version', :version, 'Aktuelle SMP-Softwareversion', NOW(), NOW())");
                            }

                            $stmt->execute([':version' => $newVersion]);
                            $currentVersion = $newVersion;
                            $message = "Frische Installation erfolgreich abgeschlossen! Neue Version: $newVersion.";
                        } catch (PDOException $e) {
                            $message = "Datenbankfehler: " . $e->getMessage();
                        }
                    } else {
                        $message = "Fehler: version_info.json enthält keine gültige Versionsnummer.";
                    }
                } else {
                    $message = "Fehler: version_info.json konnte nicht gefunden werden.";
                }
            } else {
                $message = "Fehler beim Extrahieren der NEU INSTALLATION-Dateien.";
            }
        }
    } else {
        $message = "Ungültige Aktion ausgewählt.";
    }

    // Bereinigung
    if (isset($_SESSION['temp_dir'])) {
        // Entfernen der temporären Dateien
        deleteDir($_SESSION['temp_dir']);
        unset($_SESSION['temp_dir']);
    }

    // Entfernen der hochgeladenen ZIP-Datei
    if (isset($_SESSION['uploaded_zip'])) {
        unlink($_SESSION['uploaded_zip']);
        unset($_SESSION['uploaded_zip']);
    }

    // Entfernen der Update-Struktur aus der Session
    if (isset($_SESSION['update_structure'])) {
        unset($_SESSION['update_structure']);
    }

    // Anzeige der Ergebnisnachricht
    ?>
    <!DOCTYPE html>
    <html lang="de">
    <head>
        <meta charset="UTF-8">
        <title>Update Ergebnis</title>
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <!-- Bootstrap CSS -->
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">
        <style>
            body {
                background-color: #f8f9fa;
                font-family: 'Roboto', sans-serif;
                padding-top: 50px;
            }
            .container {
                max-width: 600px;
            }
            .note {
                background-color: #fff3cd;
                border: 1px solid #ffeeba;
                padding: 15px;
                border-radius: 5px;
                margin-bottom: 20px;
            }
        </style>
    </head>
    <body>
    
    <div class="container">
        <h2 class="mb-4 text-center">Update Ergebnis</h2>
        <div class="note">
            <strong>Hinweis:</strong> Dieser Schritt kann nicht rückgängig gemacht werden. Stellen Sie sicher, dass Sie ein Backup Ihrer Daten haben.
        </div>
        <?php if (!empty($message)): ?>
            <div class="alert alert-info text-center"><?php echo htmlspecialchars($message); ?></div>
        <?php endif; ?>
        <div class="text-center mt-4">
            <a href="dashboard.php" class="btn btn-primary"><i class="bi bi-house-door-fill"></i> Zurück zum Dashboard</a>
        </div>
    </div>
    
    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    </body>
    </html>
    <?php
    exit();
}

// Schritt 4: Automatisches Update durchführen (nur UPDATE.zip)
if (isset($_GET['step']) && $_GET['step'] == 'perform_update' && isset($_SESSION['update_only_zip'])) {
    $updateZipPath = $_SESSION['update_only_zip'];
    $versionInfoPath = $_SESSION['version_info']; // Korrigierter Pfad
    $tempDir = $_SESSION['temp_dir'];
    $uploadedZip = $_SESSION['uploaded_zip'];

    $updateExtractPath = $tempDir . '/update_extracted';
    if (!mkdir($updateExtractPath, 0755, true)) {
        $message = "Fehler beim Erstellen des Update-Verzeichnisses.";
    } else {
        if (extractZip($updateZipPath, $updateExtractPath)) {
            // Kopieren der Dateien aus UPDATE.zip in das Hauptverzeichnis
            $sourceDir = $updateExtractPath;
            $destDir = __DIR__; // Hauptverzeichnis der Anwendung

            copyFiles($sourceDir, $destDir);

            // Lesen der Version aus der version_info.json
            if (file_exists($versionInfoPath)) {
                $versionData = json_decode(file_get_contents($versionInfoPath), true);
                if (isset($versionData['version'])) {
                    $newVersion = $versionData['version'];

                    // Version in die Datenbank aktualisieren
                    try {
                        $stmt = $pdo->prepare("SELECT COUNT(*) FROM settings WHERE key_name = 'version'");
                        $stmt->execute();
                        $exists = $stmt->fetchColumn();

                        if ($exists) {
                            $stmt = $pdo->prepare("UPDATE settings SET value = :version, updated_at = NOW() WHERE key_name = 'version'");
                        } else {
                            $stmt = $pdo->prepare("INSERT INTO settings (key_name, value, description, created_at, updated_at)
                                VALUES ('version', :version, 'Aktuelle SMP-Softwareversion', NOW(), NOW())");
                        }

                        $stmt->execute([':version' => $newVersion]);
                        $currentVersion = $newVersion;
                        $message = "Update erfolgreich abgeschlossen! Neue Version: $newVersion.";
                    } catch (PDOException $e) {
                        $message = "Datenbankfehler: " . $e->getMessage();
                    }
                } else {
                    $message = "Fehler: version_info.json enthält keine gültige Versionsnummer.";
                }
            } else {
                $message = "Fehler: version_info.json konnte nicht gefunden werden.";
            }
        } else {
            $message = "Fehler beim Extrahieren der UPDATE.zip-Datei.";
        }
    }

    // Bereinigung
    if (isset($_SESSION['temp_dir'])) {
        // Entfernen der temporären Dateien
        deleteDir($_SESSION['temp_dir']);
        unset($_SESSION['temp_dir']);
    }

    // Entfernen der hochgeladenen ZIP-Datei
    if (isset($_SESSION['uploaded_zip'])) {
        unlink($_SESSION['uploaded_zip']);
        unset($_SESSION['uploaded_zip']);
    }

    // Entfernen der Update-only ZIP und version_info aus der Session
    if (isset($_SESSION['update_only_zip'])) {
        unset($_SESSION['update_only_zip']);
    }
    if (isset($_SESSION['version_info'])) {
        unset($_SESSION['version_info']);
    }

    // Anzeige der Ergebnisnachricht
    ?>
    <!DOCTYPE html>
    <html lang="de">
    <head>
        <meta charset="UTF-8">
        <title>Update Ergebnis</title>
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <!-- Bootstrap CSS -->
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">
        <style>
            body {
                background-color: #f8f9fa;
                font-family: 'Roboto', sans-serif;
                padding-top: 50px;
            }
            .container {
                max-width: 600px;
            }
            .note {
                background-color: #fff3cd;
                border: 1px solid #ffeeba;
                padding: 15px;
                border-radius: 5px;
                margin-bottom: 20px;
            }
        </style>
    </head>
    <body>
    
    <div class="container">
        <h2 class="mb-4 text-center">Update Ergebnis</h2>
        <div class="note">
            <strong>Hinweis:</strong> Dieser Schritt kann nicht rückgängig gemacht werden. Stellen Sie sicher, dass Sie ein Backup Ihrer Daten haben.
        </div>
        <?php if (!empty($message)): ?>
            <div class="alert alert-info text-center"><?php echo htmlspecialchars($message); ?></div>
        <?php endif; ?>
        <div class="text-center mt-4">
            <a href="dashboard.php" class="btn btn-primary"><i class="bi bi-house-door-fill"></i> Zurück zum Dashboard</a>
        </div>
    </div>
    
    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    </body>
    </html>
    <?php
    exit();
}
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Update - SMP System</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">
    <style>
        body {
            background-color: #f8f9fa;
            font-family: 'Roboto', sans-serif;
            height: 100%;
        }
        .navbar {
            background-color: #343a40;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }
        .navbar-brand {
            font-weight: bold;
            font-size: 1.5rem;
        }
        .card {
            border-radius: 12px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            border: none;
        }
        .card-header {
            background-color: #007bff;
            color: white;
            font-weight: bold;
            text-align: center;
        }
        .btn-primary {
            background-color: #007bff;
            border: none;
            border-radius: 25px;
            padding: 10px 20px;
            font-size: 1rem;
            transition: background-color 0.3s ease;
        }
        .btn-primary:hover {
            background-color: #0056b3;
        }
        .info-box {
            background-color: #e9f7fe;
            border: 1px solid #007bff;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 20px;
            text-align: center;
        }
        .info-box a {
            text-decoration: none;
            color: #007bff;
            font-weight: bold;
        }
        .info-box a:hover {
            text-decoration: underline;
        }
        .form-control {
            border-radius: 12px;
        }
        footer {
            margin-top: 50px;
            text-align: center;
            color: #6c757d;
        }
        .note.alert-warning {
            background-color: #fff3cd;
            border-color: #ffeeba;
            color: #856404;
        }
    </style>
</head>
<body>
<!-- Navigation -->
<nav class="navbar navbar-expand-lg navbar-dark">
    <div class="container-fluid">
        <a class="navbar-brand" href="index.php"><i class="bi bi-box-seam"></i> SMP System</a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Navigation umschalten">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ms-auto">
                <li class="nav-item"><a class="nav-link" href="dashboard.php"><i class="bi bi-speedometer2"></i> Dashboard</a></li>
                <li class="nav-item"><a class="nav-link" href="lagerplaetze.php"><i class="bi bi-box"></i> Lagerplätze</a></li>
                <li class="nav-item"><a class="nav-link" href="settings.php"><i class="bi bi-gear"></i> Einstellungen</a></li>
                <li class="nav-item"><a class="nav-link" href="logout.php"><i class="bi bi-box-arrow-right"></i> Abmelden</a></li>
            </ul>
        </div>
    </div>
</nav>

<!-- Hauptinhalt -->
<div class="container mt-5">
    <div class="row justify-content-center">
        <!-- Info-Box -->
        <div class="col-md-8">
            <div class="info-box">
                <p>Benötigen Sie ein Update oder weitere Ressourcen? Besuchen Sie unseren <a href="https://smp-solution.com/download.php">Downloadbereich</a>, um die neueste Version herunterzuladen.</p>
            </div>
        </div>
        <!-- Update Card -->
        <div class="col-md-6">
            <div class="card">
                <div class="card-header">
                    <i class="bi bi-arrow-up-circle"></i> SMP System aktualisieren
                </div>
                <div class="card-body">
                    <?php if (!empty($message)): ?>
                        <div class="alert alert-info text-center"><?php echo htmlspecialchars($message); ?></div>
                    <?php endif; ?>
                    <p class="text-center mb-4"><strong>Aktuelle Version:</strong> <?php echo htmlspecialchars($currentVersion); ?></p>
                    <form method="POST" enctype="multipart/form-data">
                        <input type="hidden" name="step" value="upload">
                        <div class="mb-3">
                            <label for="update_zip" class="form-label">ZIP-Datei hochladen</label>
                            <input type="file" class="form-control" id="update_zip" name="update_zip" required>
                        </div>
                        <div class="note alert-warning">
                            <strong>Hinweis:</strong> Dieser Schritt kann nicht rückgängig gemacht werden. Stellen Sie sicher, dass Sie ein Backup Ihrer Daten haben, bevor Sie fortfahren.
                        </div>
                        <button type="submit" class="btn btn-primary w-100"><i class="bi bi-upload"></i> Update durchführen</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Footer -->
<footer>
    <p>&copy; 2024 SMP System. Alle Rechte vorbehalten.</p>
</footer>

<!-- Bootstrap JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>
